@@ -6,18 +6,9 @@
  */
 
 #pragma once
-#include <QObject>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <grantlee/filter.h>
-#else
 #include <KTextTemplate/Filter>
-#endif
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-class KDateFilter : public Grantlee::Filter
-#else
+#include <QObject>
 class KDateFilter : public KTextTemplate::Filter
-#endif
-
 {
 public:
     KDateFilter();
@@ -29,11 +20,7 @@ public:
 private:
     Q_DISABLE_COPY(KDateFilter)
 };
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-class KTimeFilter : public Grantlee::Filter
-#else
 class KTimeFilter : public KTextTemplate::Filter
-#endif
 {
 public:
     KTimeFilter();
@@ -45,11 +32,7 @@ public:
 private:
     Q_DISABLE_COPY(KTimeFilter)
 };
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-class KDateTimeFilter : public Grantlee::Filter
-#else
 class KDateTimeFilter : public KTextTemplate::Filter
-#endif
 {
 public:
     KDateTimeFilter();
